pub enum Events {
Show 17 variants
Submitted(JobSubmittedEvent),
Queued(JobQueuedEvent),
Leased(JobLeasedEvent),
LeaseReturned(JobLeaseReturnedEvent),
LeaseExpired(JobLeaseExpiredEvent),
Pending(JobPendingEvent),
Running(JobRunningEvent),
Failed(JobFailedEvent),
Succeeded(JobSucceededEvent),
Reprioritized(JobReprioritizedEvent),
Cancelling(JobCancellingEvent),
Cancelled(JobCancelledEvent),
Utilisation(JobUtilisationEvent),
IngressInfo(JobIngressInfoEvent),
Reprioritizing(JobReprioritizingEvent),
Preempted(JobPreemptedEvent),
Preempting(JobPreemptingEvent),
}Variants
Submitted(JobSubmittedEvent)
Queued(JobQueuedEvent)
Leased(JobLeasedEvent)
LeaseReturned(JobLeaseReturnedEvent)
LeaseExpired(JobLeaseExpiredEvent)
Pending(JobPendingEvent)
Running(JobRunningEvent)
Failed(JobFailedEvent)
Succeeded(JobSucceededEvent)
Reprioritized(JobReprioritizedEvent)
Cancelling(JobCancellingEvent)
Cancelled(JobCancelledEvent)
Utilisation(JobUtilisationEvent)
IngressInfo(JobIngressInfoEvent)
Reprioritizing(JobReprioritizingEvent)
Preempted(JobPreemptedEvent)
Preempting(JobPreemptingEvent)
Implementations
Sourceimpl Events
impl Events
Sourcepub fn merge(
field: &mut Option<Events>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Events>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.