pub struct IngressConfig {
pub type: i32,
pub ports: Vec<u32>,
pub annotations: HashMap<String, String>,
pub tls_enabled: bool,
pub cert_name: String,
pub use_cluster_ip: bool,
}Fields
type: i32👎Deprecated
ports: Vec<u32>annotations: HashMap<String, String>tls_enabled: boolcert_name: Stringuse_cluster_ip: boolImplementations
Sourceimpl IngressConfig
impl IngressConfig
Sourcepub fn type(&self) -> IngressType
pub fn type(&self) -> IngressType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: IngressType)
pub fn set_type(&mut self, value: IngressType)
Sets type to the provided enum value.