pub struct Job {Show 21 fields
pub id: String,
pub client_id: String,
pub job_set_id: String,
pub queue: String,
pub namespace: String,
pub labels: HashMap<String, String>,
pub annotations: HashMap<String, String>,
pub required_node_labels: HashMap<String, String>,
pub owner: String,
pub queue_ownership_user_groups: Vec<String>,
pub compressed_queue_ownership_user_groups: Vec<u8>,
pub priority: f64,
pub pod_spec: Option<PodSpec>,
pub pod_specs: Vec<PodSpec>,
pub scheduling_resource_requirements: Option<ResourceRequirements>,
pub created: Option<Timestamp>,
pub ingress: Vec<IngressConfig>,
pub services: Vec<ServiceConfig>,
pub k8s_ingress: Vec<Ingress>,
pub k8s_service: Vec<Service>,
pub scheduler: String,
}Fields
id: Stringclient_id: Stringjob_set_id: Stringqueue: Stringnamespace: Stringlabels: HashMap<String, String>annotations: HashMap<String, String>required_node_labels: HashMap<String, String>owner: Stringqueue_ownership_user_groups: Vec<String>compressed_queue_ownership_user_groups: Vec<u8>priority: f64pod_spec: Option<PodSpec>👎Deprecated
Use PodSpecs instead
pod_specs: Vec<PodSpec>scheduling_resource_requirements: Option<ResourceRequirements>Resource requests and limits necessary for scheduling the main pod of this job. The requests and limits herein are set to:
max(
sum across all containers,
max over all init containers,)
This is because containers run in parallel, whereas initContainers run serially. This field is populated automatically at submission. Submitting a job with this field already populated results in an error.
created: Option<Timestamp>ingress: Vec<IngressConfig>Services can be provided either as Armada-specific config objects or as proper k8s objects. These options are exclusive, i.e., if either ingress or services is provided, then neither of k8s_ingress or k8s_service can be provided, and vice versa.
services: Vec<ServiceConfig>k8s_ingress: Vec<Ingress>k8s_service: Vec<Service>scheduler: StringIndicates which scheduler should manage this job. If empty, the default scheduler is used.