pub struct JobRunDetails {
pub run_id: String,
pub job_id: String,
pub state: i32,
pub cluster: String,
pub node: String,
pub leased_ts: Option<Timestamp>,
pub pending_ts: Option<Timestamp>,
pub started_ts: Option<Timestamp>,
pub finished_ts: Option<Timestamp>,
pub ingress_addresses: HashMap<i32, String>,
}Fields
run_id: Stringjob_id: Stringstate: i32cluster: Stringnode: Stringleased_ts: Option<Timestamp>pending_ts: Option<Timestamp>started_ts: Option<Timestamp>finished_ts: Option<Timestamp>ingress_addresses: HashMap<i32, String>Implementations
Sourceimpl JobRunDetails
impl JobRunDetails
Sourcepub fn state(&self) -> JobRunState
pub fn state(&self) -> JobRunState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: JobRunState)
pub fn set_state(&mut self, value: JobRunState)
Sets state to the provided enum value.