pub struct JobStatusResponse {
pub job_states: HashMap<String, i32>,
}Fields
job_states: HashMap<String, i32>Implementations
Sourceimpl JobStatusResponse
impl JobStatusResponse
Sourcepub fn get_job_states(&self, key: &str) -> Option<JobState>
pub fn get_job_states(&self, key: &str) -> Option<JobState>
Returns the enum value for the corresponding key in job_states, or None if the entry does not exist or it is not a valid enum value.