pub struct PriorityClassResourceLimits {
pub maximum_resource_fraction: HashMap<String, f64>,
pub maximum_resource_fraction_by_pool: HashMap<String, PriorityClassPoolResourceLimits>,
}Fields
maximum_resource_fraction: HashMap<String, f64>Limits resources assigned to jobs of this priority class. Specifically, jobs of this priority class are only scheduled if doing so does not exceed this limit.
maximum_resource_fraction_by_pool: HashMap<String, PriorityClassPoolResourceLimits>Per-pool override of maximum_resource_fraction. If missing for a particular pool, maximum_resource_fraction is used instead for that pool.