pub struct Queue {
pub name: String,
pub priority_factor: f64,
pub user_owners: Vec<String>,
pub group_owners: Vec<String>,
pub resource_limits: HashMap<String, f64>,
pub resource_limits_by_priority_class_name: HashMap<String, PriorityClassResourceLimits>,
pub permissions: Vec<Permissions>,
pub cordoned: bool,
pub labels_deprecated: Vec<String>,
pub labels: HashMap<String, String>,
}Expand description
swagger:model
Fields
name: Stringpriority_factor: f64user_owners: Vec<String>group_owners: Vec<String>resource_limits: HashMap<String, f64>These are ignored and should be removed
resource_limits_by_priority_class_name: HashMap<String, PriorityClassResourceLimits>Map from priority class name to resource limit overrides for this queue and priority class. If provided for a priority class, global limits for that priority class do not apply to this queue.
permissions: Vec<Permissions>cordoned: boolDetermines whether scheduling is enabled for this queue.
labels_deprecated: Vec<String>👎Deprecated
A list of Kubernetes-like key-value labels, e.g. armadaproject.io/priority=critical
labels: HashMap<String, String>Trait Implementations
Sourceimpl Message for Queue
impl Message for Queue
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for Queue