pub struct ServiceConfig {
pub type: i32,
pub ports: Vec<u32>,
pub name: String,
}Fields
type: i32ports: Vec<u32>name: StringThe name of the service resource that is created. If empty a name will be generated based on the job ID.
Implementations
Sourceimpl ServiceConfig
impl ServiceConfig
Sourcepub fn type(&self) -> ServiceType
pub fn type(&self) -> ServiceType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: ServiceType)
pub fn set_type(&mut self, value: ServiceType)
Sets type to the provided enum value.