AzureDiskVolumeSource

Struct AzureDiskVolumeSource 

pub struct AzureDiskVolumeSource {
    pub disk_name: Option<String>,
    pub disk_uri: Option<String>,
    pub caching_mode: Option<String>,
    pub fs_type: Option<String>,
    pub read_only: Option<bool>,
    pub kind: Option<String>,
}
AzureDisk represents an Azure Data Disk mount on the host and bind mount to the pod.

Fields

disk_name: Option<String>

diskName is the Name of the data disk in the blob storage

disk_uri: Option<String>

diskURI is the URI of data disk in the blob storage

caching_mode: Option<String>

cachingMode is the Host Caching mode: None, Read Only, Read Write. +optional +default=ref(AzureDataDiskCachingReadWrite)

fs_type: Option<String>

fsType is Filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. “ext4”, “xfs”, “ntfs”. Implicitly inferred to be “ext4” if unspecified. +optional +default=“ext4”

read_only: Option<bool>

readOnly Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. +optional +default=false

kind: Option<String>

kind expected values are Shared: multiple blob disks per storage account Dedicated: single blob disk per storage account Managed: azure managed data disk (only in managed availability set). defaults to shared +default=ref(AzureSharedBlobDisk)

Implementations

Source

impl AzureDiskVolumeSource

pub fn disk_name(&self) -> &str

Returns the value of disk_name, or the default value if disk_name is unset.

pub fn disk_uri(&self) -> &str

Returns the value of disk_uri, or the default value if disk_uri is unset.

pub fn caching_mode(&self) -> &str

Returns the value of caching_mode, or the default value if caching_mode is unset.

pub fn fs_type(&self) -> &str

Returns the value of fs_type, or the default value if fs_type is unset.

pub fn read_only(&self) -> bool

Returns the value of read_only, or the default value if read_only is unset.

pub fn kind(&self) -> &str

Returns the value of kind, or the default value if kind is unset.