pub struct AzureFilePersistentVolumeSource {
pub secret_name: Option<String>,
pub share_name: Option<String>,
pub read_only: Option<bool>,
pub secret_namespace: Option<String>,
}Expand description
AzureFile represents an Azure File Service mount on the host and bind mount to the pod.
Fields
secret_name: Option<String>secretName is the name of secret that contains Azure Storage Account Name and Key
shareName is the azure Share Name
read_only: Option<bool>readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. +optional
secret_namespace: Option<String>secretNamespace is the namespace of the secret that contains Azure Storage Account Name and Key default is the same as the Pod +optional
Implementations
Sourceimpl AzureFilePersistentVolumeSource
impl AzureFilePersistentVolumeSource
Sourcepub fn secret_name(&self) -> &str
pub fn secret_name(&self) -> &str
Returns the value of secret_name, or the default value if secret_name is unset.
Returns the value of share_name, or the default value if share_name is unset.
Sourcepub fn read_only(&self) -> bool
pub fn read_only(&self) -> bool
Returns the value of read_only, or the default value if read_only is unset.
Sourcepub fn secret_namespace(&self) -> &str
pub fn secret_namespace(&self) -> &str
Returns the value of secret_namespace, or the default value if secret_namespace is unset.