pub struct CephFsPersistentVolumeSource {
pub monitors: Vec<String>,
pub path: Option<String>,
pub user: Option<String>,
pub secret_file: Option<String>,
pub secret_ref: Option<SecretReference>,
pub read_only: Option<bool>,
}Expand description
Represents a Ceph Filesystem mount that lasts the lifetime of a pod Cephfs volumes do not support ownership management or SELinux relabeling.
Fields
monitors: Vec<String>monitors is Required: Monitors is a collection of Ceph monitors More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it +listType=atomic
path: Option<String>path is Optional: Used as the mounted root, rather than the full Ceph tree, default is / +optional
user: Option<String>user is Optional: User is the rados user name, default is admin More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it +optional
secret_file: Option<String>secretFile is Optional: SecretFile is the path to key ring for User, default is /etc/ceph/user.secret More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it +optional
secret_ref: Option<SecretReference>secretRef is Optional: SecretRef is reference to the authentication secret for User, default is empty. More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it +optional
read_only: Option<bool>readOnly is Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/volumes/cephfs/README.md#how-to-use-it +optional
Implementations
Sourceimpl CephFsPersistentVolumeSource
impl CephFsPersistentVolumeSource
Sourcepub fn secret_file(&self) -> &str
pub fn secret_file(&self) -> &str
Returns the value of secret_file, or the default value if secret_file is unset.