pub struct CinderPersistentVolumeSource {
pub volume_id: Option<String>,
pub fs_type: Option<String>,
pub read_only: Option<bool>,
pub secret_ref: Option<SecretReference>,
}Expand description
Represents a cinder volume resource in Openstack. A Cinder volume must exist before mounting to a container. The volume must also be in the same region as the kubelet. Cinder volumes support ownership management and SELinux relabeling.
Fields
volume_id: Option<String>volumeID used to identify the volume in cinder. More info: https://examples.k8s.io/mysql-cinder-pd/README.md
fs_type: Option<String>fsType Filesystem type to mount. Must be a filesystem type supported by the host operating system. Examples: “ext4”, “xfs”, “ntfs”. Implicitly inferred to be “ext4” if unspecified. More info: https://examples.k8s.io/mysql-cinder-pd/README.md +optional
read_only: Option<bool>readOnly is Optional: Defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. More info: https://examples.k8s.io/mysql-cinder-pd/README.md +optional
secret_ref: Option<SecretReference>secretRef is Optional: points to a secret object containing parameters used to connect to OpenStack. +optional
Implementations