pub struct PersistentVolumeSource {Show 22 fields
pub gce_persistent_disk: Option<GcePersistentDiskVolumeSource>,
pub aws_elastic_block_store: Option<AwsElasticBlockStoreVolumeSource>,
pub host_path: Option<HostPathVolumeSource>,
pub glusterfs: Option<GlusterfsPersistentVolumeSource>,
pub nfs: Option<NfsVolumeSource>,
pub rbd: Option<RbdPersistentVolumeSource>,
pub iscsi: Option<IscsiPersistentVolumeSource>,
pub cinder: Option<CinderPersistentVolumeSource>,
pub cephfs: Option<CephFsPersistentVolumeSource>,
pub fc: Option<FcVolumeSource>,
pub flocker: Option<FlockerVolumeSource>,
pub flex_volume: Option<FlexPersistentVolumeSource>,
pub azure_file: Option<AzureFilePersistentVolumeSource>,
pub vsphere_volume: Option<VsphereVirtualDiskVolumeSource>,
pub quobyte: Option<QuobyteVolumeSource>,
pub azure_disk: Option<AzureDiskVolumeSource>,
pub photon_persistent_disk: Option<PhotonPersistentDiskVolumeSource>,
pub portworx_volume: Option<PortworxVolumeSource>,
pub scale_io: Option<ScaleIoPersistentVolumeSource>,
pub local: Option<LocalVolumeSource>,
pub storageos: Option<StorageOsPersistentVolumeSource>,
pub csi: Option<CsiPersistentVolumeSource>,
}Expand description
PersistentVolumeSource is similar to VolumeSource but meant for the administrator who creates PVs. Exactly one of its members must be set.
Fields
gce_persistent_disk: Option<GcePersistentDiskVolumeSource>gcePersistentDisk represents a GCE Disk resource that is attached to a kubelet’s host machine and then exposed to the pod. Provisioned by an admin. Deprecated: GCEPersistentDisk is deprecated. All operations for the in-tree gcePersistentDisk type are redirected to the pd.csi.storage.gke.io CSI driver. More info: https://kubernetes.io/docs/concepts/storage/volumes#gcepersistentdisk +optional
aws_elastic_block_store: Option<AwsElasticBlockStoreVolumeSource>awsElasticBlockStore represents an AWS Disk resource that is attached to a kubelet’s host machine and then exposed to the pod. Deprecated: AWSElasticBlockStore is deprecated. All operations for the in-tree awsElasticBlockStore type are redirected to the ebs.csi.aws.com CSI driver. More info: https://kubernetes.io/docs/concepts/storage/volumes#awselasticblockstore +optional
host_path: Option<HostPathVolumeSource>hostPath represents a directory on the host. Provisioned by a developer or tester. This is useful for single-node development and testing only! On-host storage is not supported in any way and WILL NOT WORK in a multi-node cluster. More info: https://kubernetes.io/docs/concepts/storage/volumes#hostpath +optional
glusterfs: Option<GlusterfsPersistentVolumeSource>glusterfs represents a Glusterfs volume that is attached to a host and exposed to the pod. Provisioned by an admin. Deprecated: Glusterfs is deprecated and the in-tree glusterfs type is no longer supported. More info: https://examples.k8s.io/volumes/glusterfs/README.md +optional
nfs: Option<NfsVolumeSource>nfs represents an NFS mount on the host. Provisioned by an admin. More info: https://kubernetes.io/docs/concepts/storage/volumes#nfs +optional
rbd: Option<RbdPersistentVolumeSource>rbd represents a Rados Block Device mount on the host that shares a pod’s lifetime. Deprecated: RBD is deprecated and the in-tree rbd type is no longer supported. More info: https://examples.k8s.io/volumes/rbd/README.md +optional
iscsi: Option<IscsiPersistentVolumeSource>iscsi represents an ISCSI Disk resource that is attached to a kubelet’s host machine and then exposed to the pod. Provisioned by an admin. +optional
cinder: Option<CinderPersistentVolumeSource>cinder represents a cinder volume attached and mounted on kubelets host machine. Deprecated: Cinder is deprecated. All operations for the in-tree cinder type are redirected to the cinder.csi.openstack.org CSI driver. More info: https://examples.k8s.io/mysql-cinder-pd/README.md +optional
cephfs: Option<CephFsPersistentVolumeSource>cephFS represents a Ceph FS mount on the host that shares a pod’s lifetime. Deprecated: CephFS is deprecated and the in-tree cephfs type is no longer supported. +optional
fc: Option<FcVolumeSource>fc represents a Fibre Channel resource that is attached to a kubelet’s host machine and then exposed to the pod. +optional
flocker: Option<FlockerVolumeSource>flocker represents a Flocker volume attached to a kubelet’s host machine and exposed to the pod for its usage. This depends on the Flocker control service being running. Deprecated: Flocker is deprecated and the in-tree flocker type is no longer supported. +optional
flex_volume: Option<FlexPersistentVolumeSource>flexVolume represents a generic volume resource that is provisioned/attached using an exec based plugin. Deprecated: FlexVolume is deprecated. Consider using a CSIDriver instead. +optional
azure_file: Option<AzureFilePersistentVolumeSource>azureFile represents an Azure File Service mount on the host and bind mount to the pod. Deprecated: AzureFile is deprecated. All operations for the in-tree azureFile type are redirected to the file.csi.azure.com CSI driver. +optional
vsphere_volume: Option<VsphereVirtualDiskVolumeSource>vsphereVolume represents a vSphere volume attached and mounted on kubelets host machine. Deprecated: VsphereVolume is deprecated. All operations for the in-tree vsphereVolume type are redirected to the csi.vsphere.vmware.com CSI driver. +optional
quobyte: Option<QuobyteVolumeSource>quobyte represents a Quobyte mount on the host that shares a pod’s lifetime. Deprecated: Quobyte is deprecated and the in-tree quobyte type is no longer supported. +optional
azure_disk: Option<AzureDiskVolumeSource>azureDisk represents an Azure Data Disk mount on the host and bind mount to the pod. Deprecated: AzureDisk is deprecated. All operations for the in-tree azureDisk type are redirected to the disk.csi.azure.com CSI driver. +optional
photon_persistent_disk: Option<PhotonPersistentDiskVolumeSource>photonPersistentDisk represents a PhotonController persistent disk attached and mounted on kubelets host machine. Deprecated: PhotonPersistentDisk is deprecated and the in-tree photonPersistentDisk type is no longer supported.
portworx_volume: Option<PortworxVolumeSource>portworxVolume represents a portworx volume attached and mounted on kubelets host machine. Deprecated: PortworxVolume is deprecated. All operations for the in-tree portworxVolume type are redirected to the pxd.portworx.com CSI driver when the CSIMigrationPortworx feature-gate is on. +optional
scale_io: Option<ScaleIoPersistentVolumeSource>scaleIO represents a ScaleIO persistent volume attached and mounted on Kubernetes nodes. Deprecated: ScaleIO is deprecated and the in-tree scaleIO type is no longer supported. +optional
local: Option<LocalVolumeSource>local represents directly-attached storage with node affinity +optional
storageos: Option<StorageOsPersistentVolumeSource>storageOS represents a StorageOS volume that is attached to the kubelet’s host machine and mounted into the pod. Deprecated: StorageOS is deprecated and the in-tree storageos type is no longer supported. More info: https://examples.k8s.io/volumes/storageos/README.md +optional
csi: Option<CsiPersistentVolumeSource>csi represents storage that is handled by an external CSI driver. +optional