pub struct PodAttachOptions {
pub stdin: Option<bool>,
pub stdout: Option<bool>,
pub stderr: Option<bool>,
pub tty: Option<bool>,
pub container: Option<String>,
}Expand description
PodAttachOptions is the query options to a Pod’s remote attach call.
TODO: merge w/ PodExecOptions below for stdin, stdout, etc and also when we cut V2, we should export a “StreamOptions” or somesuch that contains Stdin, Stdout, Stder and TTY
Fields
stdin: Option<bool>Stdin if true, redirects the standard input stream of the pod for this call. Defaults to false. +optional
stdout: Option<bool>Stdout if true indicates that stdout is to be redirected for the attach call. Defaults to true. +optional
stderr: Option<bool>Stderr if true indicates that stderr is to be redirected for the attach call. Defaults to true. +optional
tty: Option<bool>TTY if true indicates that a tty will be allocated for the attach call. This is passed through the container runtime so the tty is allocated on the worker node by the container runtime. Defaults to false. +optional
container: Option<String>The container in which to execute the command. Defaults to only container if there is only one container in the pod. +optional
Implementations
Sourceimpl PodAttachOptions
impl PodAttachOptions
Sourcepub fn stdin(&self) -> bool
pub fn stdin(&self) -> bool
Returns the value of stdin, or the default value if stdin is unset.
Sourcepub fn stdout(&self) -> bool
pub fn stdout(&self) -> bool
Returns the value of stdout, or the default value if stdout is unset.