RbdPersistentVolumeSource

Struct RbdPersistentVolumeSource 

pub struct RbdPersistentVolumeSource {
    pub monitors: Vec<String>,
    pub image: Option<String>,
    pub fs_type: Option<String>,
    pub pool: Option<String>,
    pub user: Option<String>,
    pub keyring: Option<String>,
    pub secret_ref: Option<SecretReference>,
    pub read_only: Option<bool>,
}
Represents a Rados Block Device mount that lasts the lifetime of a pod. RBD volumes support ownership management and SELinux relabeling.

Fields

monitors: Vec<String>

monitors is a collection of Ceph monitors. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it +listType=atomic

image: Option<String>

image is the rados image name. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it

fs_type: Option<String>

fsType is the filesystem type of the volume that you want to mount. Tip: Ensure that the filesystem type is supported by the host operating system. Examples: “ext4”, “xfs”, “ntfs”. Implicitly inferred to be “ext4” if unspecified. More info: https://kubernetes.io/docs/concepts/storage/volumes#rbd TODO: how do we prevent errors in the filesystem from compromising the machine +optional

pool: Option<String>

pool is the rados pool name. Default is rbd. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it +optional +default=“rbd”

user: Option<String>

user is the rados user name. Default is admin. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it +optional +default=“admin”

keyring: Option<String>

keyring is the path to key ring for RBDUser. Default is /etc/ceph/keyring. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it +optional +default=“/etc/ceph/keyring”

secret_ref: Option<SecretReference>

secretRef is name of the authentication secret for RBDUser. If provided overrides keyring. Default is nil. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it +optional

read_only: Option<bool>

readOnly here will force the ReadOnly setting in VolumeMounts. Defaults to false. More info: https://examples.k8s.io/volumes/rbd/README.md#how-to-use-it +optional

Implementations

Source

impl RbdPersistentVolumeSource

pub fn image(&self) -> &str

Returns the value of image, or the default value if image is unset.

pub fn fs_type(&self) -> &str

Returns the value of fs_type, or the default value if fs_type is unset.

pub fn pool(&self) -> &str

Returns the value of pool, or the default value if pool is unset.

pub fn user(&self) -> &str

Returns the value of user, or the default value if user is unset.

pub fn keyring(&self) -> &str

Returns the value of keyring, or the default value if keyring is unset.

pub fn read_only(&self) -> bool

Returns the value of read_only, or the default value if read_only is unset.