pub struct ReplicationController {
pub metadata: Option<ObjectMeta>,
pub spec: Option<ReplicationControllerSpec>,
pub status: Option<ReplicationControllerStatus>,
}Expand description
ReplicationController represents the configuration of a replication controller.
Fields
metadata: Option<ObjectMeta>If the Labels of a ReplicationController are empty, they are defaulted to be the same as the Pod(s) that the replication controller manages. Standard object’s metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata +optional
spec: Option<ReplicationControllerSpec>Spec defines the specification of the desired behavior of the replication controller. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status +optional
status: Option<ReplicationControllerStatus>Status is the most recently observed status of the replication controller. This data may be out of date by some window of time. Populated by the system. Read-only. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#spec-and-status +optional