pub struct ReplicationControllerStatus {
pub replicas: Option<i32>,
pub fully_labeled_replicas: Option<i32>,
pub ready_replicas: Option<i32>,
pub available_replicas: Option<i32>,
pub observed_generation: Option<i64>,
pub conditions: Vec<ReplicationControllerCondition>,
}Expand description
ReplicationControllerStatus represents the current status of a replication controller.
Fields
replicas: Option<i32>Replicas is the most recently observed number of replicas. More info: https://kubernetes.io/docs/concepts/workloads/controllers/replicationcontroller#what-is-a-replicationcontroller
fully_labeled_replicas: Option<i32>The number of pods that have labels matching the labels of the pod template of the replication controller. +optional
ready_replicas: Option<i32>The number of ready replicas for this replication controller. +optional
available_replicas: Option<i32>The number of available replicas (ready for at least minReadySeconds) for this replication controller. +optional
observed_generation: Option<i64>ObservedGeneration reflects the generation of the most recently observed replication controller. +optional
conditions: Vec<ReplicationControllerCondition>Represents the latest available observations of a replication controller’s current state. +optional +patchMergeKey=type +patchStrategy=merge +listType=map +listMapKey=type
Implementations
Sourceimpl ReplicationControllerStatus
impl ReplicationControllerStatus
Sourcepub fn replicas(&self) -> i32
pub fn replicas(&self) -> i32
Returns the value of replicas, or the default value if replicas is unset.
Sourcepub fn fully_labeled_replicas(&self) -> i32
pub fn fully_labeled_replicas(&self) -> i32
Returns the value of fully_labeled_replicas, or the default value if fully_labeled_replicas is unset.
Sourcepub fn observed_generation(&self) -> i64
pub fn observed_generation(&self) -> i64
Returns the value of observed_generation, or the default value if observed_generation is unset.
Sourcepub fn ready_replicas(&self) -> i32
pub fn ready_replicas(&self) -> i32
Returns the value of ready_replicas, or the default value if ready_replicas is unset.
Sourcepub fn available_replicas(&self) -> i32
pub fn available_replicas(&self) -> i32
Returns the value of available_replicas, or the default value if available_replicas is unset.