pub struct ScaleIoPersistentVolumeSource {
pub gateway: Option<String>,
pub system: Option<String>,
pub secret_ref: Option<SecretReference>,
pub ssl_enabled: Option<bool>,
pub protection_domain: Option<String>,
pub storage_pool: Option<String>,
pub storage_mode: Option<String>,
pub volume_name: Option<String>,
pub fs_type: Option<String>,
pub read_only: Option<bool>,
}Expand description
ScaleIOPersistentVolumeSource represents a persistent ScaleIO volume
Fields
gateway: Option<String>gateway is the host address of the ScaleIO API Gateway.
system: Option<String>system is the name of the storage system as configured in ScaleIO.
secret_ref: Option<SecretReference>secretRef references to the secret for ScaleIO user and other sensitive information. If this is not provided, Login operation will fail.
ssl_enabled: Option<bool>sslEnabled is the flag to enable/disable SSL communication with Gateway, default false +optional
protection_domain: Option<String>protectionDomain is the name of the ScaleIO Protection Domain for the configured storage. +optional
storage_pool: Option<String>storagePool is the ScaleIO Storage Pool associated with the protection domain. +optional
storage_mode: Option<String>storageMode indicates whether the storage for a volume should be ThickProvisioned or ThinProvisioned. Default is ThinProvisioned. +optional +default=“ThinProvisioned”
volume_name: Option<String>volumeName is the name of a volume already created in the ScaleIO system that is associated with this volume source.
fs_type: Option<String>fsType is the filesystem type to mount. Must be a filesystem type supported by the host operating system. Ex. “ext4”, “xfs”, “ntfs”. Default is “xfs” +optional +default=“xfs”
read_only: Option<bool>readOnly defaults to false (read/write). ReadOnly here will force the ReadOnly setting in VolumeMounts. +optional
Implementations
Sourceimpl ScaleIoPersistentVolumeSource
impl ScaleIoPersistentVolumeSource
Sourcepub fn gateway(&self) -> &str
pub fn gateway(&self) -> &str
Returns the value of gateway, or the default value if gateway is unset.
Sourcepub fn system(&self) -> &str
pub fn system(&self) -> &str
Returns the value of system, or the default value if system is unset.
Sourcepub fn ssl_enabled(&self) -> bool
pub fn ssl_enabled(&self) -> bool
Returns the value of ssl_enabled, or the default value if ssl_enabled is unset.
Sourcepub fn protection_domain(&self) -> &str
pub fn protection_domain(&self) -> &str
Returns the value of protection_domain, or the default value if protection_domain is unset.
Sourcepub fn storage_pool(&self) -> &str
pub fn storage_pool(&self) -> &str
Returns the value of storage_pool, or the default value if storage_pool is unset.
Sourcepub fn storage_mode(&self) -> &str
pub fn storage_mode(&self) -> &str
Returns the value of storage_mode, or the default value if storage_mode is unset.
Sourcepub fn volume_name(&self) -> &str
pub fn volume_name(&self) -> &str
Returns the value of volume_name, or the default value if volume_name is unset.